@@ -111,6 +111,57 @@ def get_PollutantVolumeChange(db, FirstOrder=None, SecondOrder=None):
     return data
 
 
+def get_ImpurityVolume(db, Target, FirstOrder='FacilityReportID', ReleaseMediumName='Air', absolute=False, FacilityFocus=True, Impurity=None):
+    """
+    Creates a table with the impurities of the target pollutant, sorted by the FirstOrder parameter. Putting the absolute parameter to True, gives absolute values instead of relative.
+
+    Parameters
+    ----------
+    db : DataFrame
+        Data to look for impurities.
+    Target : String
+        Pollutant name of the pollutant, which is not seen as impurity.
+    FirstOrder : String, optional
+        Order to sort the impurities by. E.g. NACERegionGeoCode, FacilityReportID, NACEMainEconomicActivityCode. The default is 'FacilityReportID'.
+    ReleaseMediumName : String, optional
+        The release medium name in which the target is emitted and in which can be impurities. The default is 'Air'.
+    absolute : Boolean, optional
+        If this parameter is set on False, this function returns the impurity relative to the target pollutant emission. If it is set on True, the absolute emission value is returned. The default is False.
+    FacilityFocus : Boolean, optional
+        If this parameter is true, only the impurities in the facilities in which the target is emittet is taken in to consideration. If it is false, all data are taken into consideration. The default is True.
+    Impurity : String, optional
+        With this parameter, you can specify the impurity pollutant you want to return. Otherwise, all present impurities are shown. The default is None.
+
+    Returns
+    -------
+    d2 : DataFrame
+        Data table with the rows beeing the different present order values, and in the columns their respective emission of the target pollutant and the absolute emission of the impurities.
+    d3 : DataFrame
+        Data table with the rows beeing the different present order values, and in the columns their respective emission of the target pollutant and the relative emission of the impurities.
+
+    """
+    db = db[db.ReleaseMediumName == ReleaseMediumName]
+    d1 = db[db.PollutantName == Target]
+    d2 = get_PollutantVolume(d1, FirstOrder=FirstOrder)
+    d3 = get_PollutantVolume(d1, FirstOrder=FirstOrder)
+    if FacilityFocus == True:
+        ff = get_PollutantVolume(d1, FirstOrder='FacilityReportID').FacilityReportID.unique()
+        db = db[db.FacilityReportID.isin(ff)]
+    for items in np.delete(db.PollutantName.unique(), np.argwhere(db.PollutantName.unique() == Target)):
+        item = db[db.PollutantName == items].groupby([FirstOrder]).TotalQuantity.sum().reset_index()
+        item = item[[FirstOrder, 'TotalQuantity']].rename(columns={'TotalQuantity': items})
+        d2 = d2.merge(item, how='left', on=FirstOrder)
+        d3[items] = d2.loc[:, items] / d2.loc[:, 'TotalQuantity']
+
+    if Impurity != None:
+        d2 = d2[[FirstOrder, 'TotalQuantity', Impurity]]
+        d3 = d3[[FirstOrder, 'TotalQuantity', Impurity]]
+    if absolute == True:
+        return d2
+    else:
+        return d3
+
+
 def plot_PollutantVolume(db, FirstOrder=None, SecondOrder=None, stacked=False, *args, **kwargs):
     """
 
@@ -123,7 +174,7 @@ def plot_PollutantVolume(db, FirstOrder=None, SecondOrder=None, stacked=False, *
     FirstOrder : String, optional
         Name of column, the data are sorted in the first order. The default is None.
     SecondOrder : String, optional
-        Name of column, the data are sorted in the second order.. The default is None.
+        Name of column, the data are sorted in the second order. The default is None.
     stacked : Boolean, optional
         Stacks the bars for second order. The default is False.
     *args : TYPE
@@ -222,6 +273,44 @@ def plot_PollutantVolume_rel(db, FirstOrder=None, SecondOrder=None, stacked=Fals
     return ax
 
 
+def plot_ImpurityVolume(db, Target, Impurity, FirstOrder='FacilityReportID', ReleaseMediumName='Air', Statistics=True, *args, **kwargs):
+    """
+    Plots the impurities for the different FirstOrder values or the statistics of the entries.
+
+    Parameters
+    ----------
+    db : DataFrame
+        The data to be plotted.
+    Target : String
+        The target pollutant which is impured.
+    Impurity : String
+        The impurity which is to be analyzed.
+    FirstOrder : String, optional
+        Name of column, the data are sorted in the first order. The default is 'FacilityReportID'.
+    ReleaseMediumName : TYPE, optional
+        The release medium name in which the target is emitted and in which can be impurities. The default is 'Air'.
+    Statistics : Boolean, optional
+        If this parameter is True, the statistics of the data are plotted. If it is False, the actual values are plotted. The default is True.
+    *args : TYPE
+        pandas.plot() input variables.
+    **kwargs : TYPE
+        pandas.plot() input variables.
+
+    Returns
+    -------
+    ax : Axes
+        Plot of the impurities in db, or the statistics of these impurities.
+
+    """
+    if Statistics is True:
+        data = get_ImpurityVolume(db=db, Target=Target, FirstOrder=FirstOrder, ReleaseMediumName=ReleaseMediumName, Impurity=Impurity).describe()
+        ax = data.drop('count').plot(kind='bar', y=Impurity, *args, **kwargs)
+    else:
+        data = get_ImpurityVolume(db=db, Target=Target, FirstOrder=FirstOrder, ReleaseMediumName=ReleaseMediumName, Impurity=Impurity)
+        ax = data.drop('TotalQuantity', axis=1).plot(x=FirstOrder, y=Impurity, kind='bar', *args, **kwargs)
+    return ax
+
+
 def get_mb_borders(mb):
     """
     Generates a list with the borders of the objects of a GeoDataFrame.
